---
title: Variables et Types
lang: fr
sidebar:
  order: 2
---

En Java, comme dans plusieurs langages de programmation, l'information est
stockée dans des [variables](#variables). Ces variables ont toutes un
[type](#types), qui permet de déterminer ce qu'elles peuvent contenir.

## Variables

Une variable représente un espace en mémoire pour stocker de l'information.
Chaque variable a un **nom**, un **type** et contient de l'information. Pour
créer un variable, on l'écrit `type nom = valeur`. À savoir que la valeur est
optionnelle, car elle peut être donnée plus tard.

## Types

Il existe plusieurs types pour les variables, certains sont inclus avec Java,
mais il est aussi possible pour vous d'en créer. Certains types ne font que
stocker une donnée, ils sont donc de types [primitifs](#primitifs). D'autres ont
aussi de la fonctionnalité, ce sont des [classes](#classes).

### Primitifs

Les types primitifs ne font que stocker de la donnée. En Java, il existe 8 types
primitifs qui permettent de stocker des **nombres**, **caractères** et
**vrai/faux**.

Voici les différents types primitifs

| **Type**    | **Stockage**                                 |
| ----------- | -------------------------------------------- |
| _`int`_     | _Nombre entier_                              |
| `byte`      | Peut stocker n'importe quoi, mais très petit |
| `short`     | Petit nombre entier                          |
| `long`      | Très grand nombre entier                     |
| `float`     | Nombre à virgule                             |
| _`double`_  | _Nombre à virgule plus précis_               |
| _`boolean`_ | _Vrai/Faux_                                  |
| `char`      | Caractère                                    |

:::note

Les types en italique (`int`, `double`, `boolean`) sont les plus utiles.

:::

Voici comment créer un `double`:

```java
double nombre = 4.2;
```

### Classes

Les classes permettent d'ajouter de la fonctionnalité à une variable. Elles
permettent aussi de regrouper plusieurs variables ensemble. On les reconnait par
le fait que leur nom commence par une majuscule (les types primitifs commencent
tous par une minuscule). Un exemple de classe qui vient avec Java est le
`String`, qui contient une chaine de caractères (`char`). Ça permet alors de
stocker des mots ou des phrases. Les `string` ajoute aussi quelques
fonctionnalités qui permettent de séparer une phrase en mots ou de savoir la
longueur de la chaine de caractère par exemple.

:::info

Plus d'information sur les classes est donnée dans la section
[classes](/java/classes).

:::

Voici comment créer un `String`:

```java
String phrase = "Hello World!";
```

:::note

Vous remarquez que dans les exemples sur cette page, les lignes finissent toutes
par `;`.

:::
